@@ -1,6 +1,6 @@
 package Alien::KentSrc;
 
-our $VERSION = '0.3';
+our $VERSION = '0.4';
 
 use strict;
 use warnings;
@@ -20,10 +20,21 @@ __END__
 
 =head1 NAME
 
-Alien::KentSrc - Fetch/build/stash Kent src from http://hgdownload.cse.ucsc.edu/admin/
+Alien::KentSrc - Fetch/build/stash Kent src from L<http://hgdownload.cse.ucsc.edu/admin/>
 
 =begin HTML
 
+<a href="#">
+  <img src="https://img.shields.io/badge/perl-5.8.9+-blue.svg"
+       alt="Requires Perl 5.8.9+" />
+</a>
+
+<!-- CPAN -->
+<a href="https://metacpan.org/pod/Alien::KentSrc">
+  <img src="https://img.shields.io/cpan/v/Alien-KentSrc.svg"
+       alt="CPAN" />
+</a>
+
 <!-- Travis -->
 <a href="https://travis-ci.org/kiwiroy/alien-kentsrc">
   <img src="https://travis-ci.org/kiwiroy/alien-kentsrc.svg?branch=master"
@@ -57,4 +68,18 @@ defines the following new methods.
 
 Return the B<MACHTYPE> that I<jkweb.a> was built with.
 
+=head1 AUTHOR
+
+Roy Storey <kiwiroy@cpan.org>
+
+=head1 SEE ALSO
+
+=over 4
+
+=item L<http://hgdownload.cse.ucsc.edu/downloads.html#source_downloads>
+
+=item L<http://kentinformatics.com>
+
+=back
+
 =cut
